#!/usr/bin/tclsh

#    This script is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Thsi script is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Foobar. If not, see <http://www.gnu.org/licenses/>.

# Usage: tclsh 7wonders_solo.tcl <LEADER>
# Leader name as in the manual.

# check for leader name and set color and extra turn symbol
switch [lindex $argv 0] {
    "Aristotele" {
        puts "Progress tokens: Law and Mathematics"
        set primaryColor "grey  "
        set etCirc "   => extra turn"
        set etTria ""
    }
    "Bilkis"     { 
        puts "Progress tokens: Economy"
        set primaryColor "brown "
        set etCirc "   => extra turn"
        set etTria "   => extra turn"
    }
    "Caesar"     {
        puts "Progress tokens: Strategy"
        set primaryColor "purple"
        set etCirc ""
        set etTria ""
        
    }
    "Cleopatra"  {
        puts "Progress tokens: Agricultur and Philosophy"
        set primaryColor "blue  "
        set etCirc ""
        set etTria "   => extra turn"
    }
    "Hammurabi"  {
        puts "Progress tokens: Economy and 5 additional victory points"
        set primaryColor "yellow"
        set etCirc "   => extra turn"
        set etTria ""
    }
    default      {
        if { [string length [lindex $argv 0]] == 0 } {
            puts "No leader given."
        } else {
            puts "Unknown leader '[lindex $argv 0]'."
        }
        puts "Allowed leaders: Aristotele Bilkis Caesar Cleopatra Hammurabi"
        exit
    }
}

# predefined values
set red   "red   "
set green "green "
set left  "<-"
set right "->"
set noet ""

# initial decision deck
set deck {}
lappend deck "$right $green $red $primaryColor $noet"
lappend deck "$right $green $red $primaryColor $noet"
lappend deck "$right $green $red $primaryColor $noet"
lappend deck "$right $red $green $primaryColor $noet"
lappend deck "$right $red $green $primaryColor $noet"
lappend deck "$right $primaryColor $red $green $etTria"
lappend deck "$left $red $green $primaryColor $noet"
lappend deck "$left $red $green $primaryColor $noet"
lappend deck "$left $red $green $primaryColor $noet"
lappend deck "$left $green $red $primaryColor $noet"
lappend deck "$left $green $red $primaryColor $noet"
lappend deck "$left $primaryColor $green $red $etCirc"

# shuffle given list and return it shuffled
proc shuffle {data} {
    set length [llength $data]
    for {set idx_1 0} {$idx_1 < $length} {incr idx_1} {
        set idx_2 [expr {int($length * rand())}]
        set temp [lindex $data $idx_1]
        lset data $idx_1 [lindex $data $idx_2]
        lset data $idx_2 $temp
    }
    return $data
}

# Pause and wait for Enter key
proc pause { } {
    flush stdout
    gets stdin
}

puts "Game starts ... Just hit 'Enter' for new turn. Hit 'Strg-C' for end script."
set counter 0
set extraTurnText ""
while { 1 } {
    # if counter 0 (start of new deck, we shuffle it)
    if { $counter == 0 } {
        set deck [shuffle $deck]
        puts "Deck shuffled ..."
    }
    # get next card
    set decisionCard [lindex $deck $counter]
    puts -nonewline "$decisionCard"
    pause
    # Increase counter
    # if end of deck reached start again (modulo)
    set counter [expr ($counter+1)%[llength $deck]]
}


